import { Component, Prop, h, Host, Element, Event, State } from "@stencil/core";
export class AccordionItem {
    constructor() {
        /**
         * The presence of this attribute makes the accordion-item disabled and not focusable
         */
        this.disabled = false;
        /**
         * The presence of this attribute makes the accordion title editable
         */
        this.editableTitle = false;
        /**
         * The accordion flavor (No need to set this attribute on each of the the accordion-item's, only once at gxg-accordion)
         */
        this.mode = "classical";
        /*The accordion padding (internal spacing)*/
        this.padding = "xs";
        /**
         * Set the status to "open" if you want the accordion-item open by default
         */
        this.status = "closed";
        /*
         *If this accordion is nested into an accordion-item
         */
        this.nestedAccordion = false;
        /*
         *accordion min-height
         */
        this.minHeight = null;
    }
    itemClickedHandler(e) {
        if (e.detail != 0) {
            this.accordionItemClicked.emit(this.itemId);
        }
    }
    titleClickedHandler() {
        this.accordionTitleClicked.emit("title clicked");
    }
    printIcon() {
        let iType;
        let iColor;
        let iSize;
        if (this.status === "open" && !this.disabled) {
            iType = "navigation/chevron-up";
            if (this.mode === "classical") {
                iColor = "alwaysblack";
            }
            else if (this.mode === "boxed" || this.mode === "minimal") {
                iColor = "onbackground";
            }
            else {
                iColor = "negative";
            }
        }
        else {
            //item closed
            iType = "navigation/chevron-down";
            if (this.mode === "classical") {
                if (this.disabled) {
                    iColor = "alwaysblack";
                }
                else {
                    //item not disabled
                    iColor = "alwaysblack";
                }
            }
            else if (this.mode === "boxed" || this.mode === "minimal") {
                if (this.disabled) {
                    iColor = "disabled";
                }
                else {
                    iColor = "onbackground";
                }
            }
            else {
                //item alternate
                iColor = "negative";
            }
        }
        if (this.mode === "classical" || this.mode === "boxed") {
            iSize = "regular";
        }
        else {
            iSize = "small";
        }
        return (h("gxg-icon", { slot: "icon", size: iSize, type: iType, color: iColor }));
    }
    componentWillLoad() {
        if (!this.itemId) {
            console.warn("gxg-accordion-item 'itemId' property is mandatory.");
        }
        this.accordionItemLoaded.emit(this.itemId);
    }
    componentDidLoad() {
        //Detect if this accordion-item has an accordion in it
        const accordion = this.el.querySelector("gxg-accordion");
        if (accordion !== null) {
            this.nestedAccordion = true;
        }
        //Detect click on input ".outer-wrapper"
        const outerWrapper = this.el.shadowRoot
            .querySelector("gxg-form-text")
            .shadowRoot.querySelector(".outer-wrapper");
        outerWrapper.addEventListener("click", function (e) {
            if (!e.path[0].classList.contains("input")) {
                this.status = "closed";
            }
        }.bind(this));
    }
    ariaExpanded() {
        if (this.status === "closed") {
            return "false";
        }
        else {
            return "true";
        }
    }
    ariaDisabled() {
        if (this.disabled) {
            return "true";
        }
        else {
            return "false";
        }
    }
    gxgFormTextClickedHandler(e) {
        e.stopPropagation();
    }
    textStyle() {
        if (this.mode === "classical") {
            return "title-05";
        }
        else if (this.mode === "slim" || this.mode === "minimal") {
            return "title-03";
        }
        else if (this.mode === "boxed") {
            return "title-02";
        }
    }
    changedTitleHandler(event) {
        if (this.editableTitle) {
            this.itemTitle = event.detail;
            this.titleChanged.emit(this.itemTitle);
        }
    }
    render() {
        return (h(Host, { class: {
                "nested-acordion": this.nestedAccordion
            } },
            h("div", { class: {
                    item: true,
                    "item--disabled": this.disabled === true
                } },
                h("header", { class: "item__header" },
                    h("div", { class: "item__header__button", id: "accordion-" + this.itemId, onClick: this.itemClickedHandler.bind(this), tabindex: !this.disabled ? 0 : -1, "aria-expanded": this.ariaExpanded(), "aria-controls": this.itemId, "aria-disabled": this.ariaDisabled() },
                        h("div", { class: {
                                cover: true,
                                hidden: this.status === "open"
                            } }),
                        h("div", { class: "item__header__button__title-subtitle" },
                            h("div", { class: "item__header__button__title-subtitle__title", onClick: this.titleClickedHandler.bind(this) }, this.editableTitle ? (h("gxg-form-text", { onChange: event => this.changedTitleHandler(event), minimal: true, value: this.itemTitle, onClick: this.gxgFormTextClickedHandler.bind(this), "text-style": this.textStyle(), class: "input" })) : (this.itemTitle)),
                            this.mode === "classical" || this.mode === "boxed" ? (h("div", { class: "item__header__button__title-subtitle__subtitle" },
                                h("slot", { name: "subtitle" }))) : null),
                        h("div", { class: "item__header__button__meta-icon-wrapper" },
                            this.mode === "boxed" ? (h("div", { class: "item__header__button__meta-icon-wrapper__meta" },
                                h("slot", { name: "meta" }))) : null,
                            h("div", { class: "item__header__button__meta-icon-wrapper__icon" }, this.printIcon())))),
                this.status === "open" && !this.disabled ? (h("div", { class: "item__container", id: this.itemId, role: "region", "aria-labelledby": "accordion-" + this.itemId },
                    h("slot", null))) : (""))));
    }
    static get is() { return "gxg-accordion-item"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() { return {
        "$": ["accordion-item.scss"]
    }; }
    static get styleUrls() { return {
        "$": ["accordion-item.css"]
    }; }
    static get properties() { return {
        "disabled": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The presence of this attribute makes the accordion-item disabled and not focusable"
            },
            "attribute": "disabled",
            "reflect": true,
            "defaultValue": "false"
        },
        "editableTitle": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The presence of this attribute makes the accordion title editable"
            },
            "attribute": "editable-title",
            "reflect": false,
            "defaultValue": "false"
        },
        "mode": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "mode",
                "resolved": "\"boxed\" | \"classical\" | \"minimal\" | \"slim\"",
                "references": {
                    "mode": {
                        "location": "import",
                        "path": "../accordion/accordion"
                    }
                }
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The accordion flavor (No need to set this attribute on each of the the accordion-item's, only once at gxg-accordion)"
            },
            "attribute": "mode",
            "reflect": true,
            "defaultValue": "\"classical\""
        },
        "itemId": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": true,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The accordion id"
            },
            "attribute": "item-id",
            "reflect": false
        },
        "itemTitle": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The accordion title"
            },
            "attribute": "item-title",
            "reflect": false
        },
        "padding": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "padding",
                "resolved": "\"0\" | \"l\" | \"m\" | \"s\" | \"xs\"",
                "references": {
                    "padding": {
                        "location": "local"
                    }
                }
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "padding",
            "reflect": true,
            "defaultValue": "\"xs\""
        },
        "status": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "status",
                "resolved": "\"closed\" | \"open\"",
                "references": {
                    "status": {
                        "location": "local"
                    }
                }
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "Set the status to \"open\" if you want the accordion-item open by default"
            },
            "attribute": "status",
            "reflect": true,
            "defaultValue": "\"closed\""
        }
    }; }
    static get states() { return {
        "nestedAccordion": {},
        "minHeight": {}
    }; }
    static get events() { return [{
            "method": "accordionItemClicked",
            "name": "accordionItemClicked",
            "bubbles": true,
            "cancelable": true,
            "composed": true,
            "docs": {
                "tags": [],
                "text": "This event is for internal use"
            },
            "complexType": {
                "original": "any",
                "resolved": "any",
                "references": {}
            }
        }, {
            "method": "accordionItemLoaded",
            "name": "accordionItemLoaded",
            "bubbles": true,
            "cancelable": true,
            "composed": true,
            "docs": {
                "tags": [],
                "text": "This event is for internal use"
            },
            "complexType": {
                "original": "any",
                "resolved": "any",
                "references": {}
            }
        }, {
            "method": "accordionTitleClicked",
            "name": "accordionTitleClicked",
            "bubbles": true,
            "cancelable": true,
            "composed": true,
            "docs": {
                "tags": [],
                "text": "Subscribe to this event to know when the \"title\" was clicked"
            },
            "complexType": {
                "original": "any",
                "resolved": "any",
                "references": {}
            }
        }, {
            "method": "titleChanged",
            "name": "titleChanged",
            "bubbles": true,
            "cancelable": true,
            "composed": true,
            "docs": {
                "tags": [],
                "text": "If \"editable-title\" attribute is present, this event emmits the title value when it has changed"
            },
            "complexType": {
                "original": "any",
                "resolved": "any",
                "references": {}
            }
        }]; }
    static get elementRef() { return "el"; }
}
