import { Component, Prop, h, Host } from "@stencil/core";
export class Box {
    constructor() {
        /*********************************
        PROPERTIES & STATE
        *********************************/
        /**
         * The background color
         */
        this.background = "surface";
        /**
         * The border type
         */
        this.border = "no-border";
        /*The box padding (internal spacing)*/
        this.padding = "xs";
        /**
         * The component min. height
         */
        this.minHeight = "auto";
        /**
         * The component max. width
         */
        this.maxWidth = "100%";
    }
    /*********************************
    METHODS
    *********************************/
    render() {
        return (h(Host, { role: "article", class: {
                card: true
            }, style: { maxWidth: this.maxWidth, minHeight: this.minHeight } },
            h("slot", null)));
    }
    static get is() { return "gxg-box"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() { return {
        "$": ["box.scss"]
    }; }
    static get styleUrls() { return {
        "$": ["box.css"]
    }; }
    static get properties() { return {
        "background": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "background",
                "resolved": "\"gray-01\" | \"gray-02\" | \"surface\"",
                "references": {
                    "background": {
                        "location": "local"
                    }
                }
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The background color"
            },
            "attribute": "background",
            "reflect": true,
            "defaultValue": "\"surface\""
        },
        "border": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "border",
                "resolved": "\"gray-03\" | \"no-border\"",
                "references": {
                    "border": {
                        "location": "local"
                    }
                }
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The border type"
            },
            "attribute": "border",
            "reflect": true,
            "defaultValue": "\"no-border\""
        },
        "padding": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "padding",
                "resolved": "\"0\" | \"l\" | \"m\" | \"s\" | \"xl\" | \"xs\" | \"xxl\" | \"xxxl\"",
                "references": {
                    "padding": {
                        "location": "local"
                    }
                }
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "padding",
            "reflect": true,
            "defaultValue": "\"xs\""
        },
        "minHeight": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The component min. height"
            },
            "attribute": "min-height",
            "reflect": false,
            "defaultValue": "\"auto\""
        },
        "maxWidth": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The component max. width"
            },
            "attribute": "max-width",
            "reflect": false,
            "defaultValue": "\"100%\""
        }
    }; }
}
