import { Component, Element, Prop, h, Host, Watch } from "@stencil/core";
export class Modal {
    constructor() {
        /*The accordion padding (internal spacing)*/
        this.padding = "s";
        /**
         * The modal width
         */
        this.width = "304px";
        /**
         * Wether the modal is visible or not
         */
        this.visible = false;
        /**
         * The z-index value of the modal
         */
        this.zIndex = "10";
    }
    componentDidLoad() {
        this.el.style.display = "block";
        this.el.style.zIndex = "-1";
    }
    closeModal() {
        this.visible = false;
    }
    watchHandler(newValue) {
        const modal = this.el;
        if (newValue === true) {
            this.el.removeAttribute("hidden");
            this.el.style.zIndex = this.zIndex;
            setTimeout(function () {
                modal.classList.add("visible");
            }, 250);
        }
        else {
            modal.classList.remove("visible");
            setTimeout(function () {
                modal.setAttribute("hidden", "hidden");
                modal.style.zIndex = "-1";
            }, 500);
        }
    }
    modalHidden() {
        if (this.visible) {
            return "false";
        }
        else {
            return "true";
        }
    }
    render() {
        return (h(Host, { role: "dialog", "aria-hidden": this.modalHidden(), hidden: true, style: { "z-index": this.zIndex, display: "none" } },
            h("div", { class: "modal", style: { width: this.width } },
                h("header", { class: "modal__header" },
                    h("span", { class: "modal__header__title" }, this.modalTitle),
                    h("gxg-button", { icon: "gemini-tools/close", type: "secondary-icon-only", onClick: this.closeModal.bind(this) })),
                h("div", { class: "modal__container" },
                    h("slot", null)),
                h("footer", { class: {
                        modalFooter: true
                    } },
                    h("slot", { name: "footer" }))),
            h("div", { class: "layer" })));
    }
    static get is() { return "gxg-modal"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() { return {
        "$": ["modal.scss"]
    }; }
    static get styleUrls() { return {
        "$": ["modal.css"]
    }; }
    static get properties() { return {
        "padding": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "padding",
                "resolved": "\"0\" | \"l\" | \"m\" | \"s\" | \"xl\" | \"xs\" | \"xxl\" | \"xxxl\"",
                "references": {
                    "padding": {
                        "location": "local"
                    }
                }
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "padding",
            "reflect": true,
            "defaultValue": "\"s\""
        },
        "modalTitle": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The modal title"
            },
            "attribute": "modal-title",
            "reflect": false
        },
        "width": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The modal width"
            },
            "attribute": "width",
            "reflect": false,
            "defaultValue": "\"304px\""
        },
        "visible": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "Wether the modal is visible or not"
            },
            "attribute": "visible",
            "reflect": false,
            "defaultValue": "false"
        },
        "zIndex": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The z-index value of the modal"
            },
            "attribute": "z-index",
            "reflect": false,
            "defaultValue": "\"10\""
        }
    }; }
    static get elementRef() { return "el"; }
    static get watchers() { return [{
            "propName": "visible",
            "methodName": "watchHandler"
        }]; }
}
