import { Component, Prop, h, Host, State } from "@stencil/core";
export class Toolbar {
    constructor() {
        /**
         * The toggle arrow position
         */
        this.position = "bottom";
        /**
         * The state of the toggle, wether is disabled or not
         */
        this.disabled = false;
        /**
         * Reading direction
         */
        this.rtl = false;
    }
    componentDidLoad() {
        //Reading Direction
        const dirHtml = document
            .getElementsByTagName("html")[0]
            .getAttribute("dir");
        const dirBody = document
            .getElementsByTagName("body")[0]
            .getAttribute("dir");
        if (dirHtml === "rtl" || dirBody === "rtl") {
            this.rtl = true;
        }
    }
    render() {
        return (h(Host, { class: {} },
            h("div", { class: {
                    toolbar: true,
                    "toolbar--start": this.position === "start",
                    "toolbar--top": this.position === "top",
                    "toolbar--bottom": this.position === "bottom",
                    rtl: this.rtl
                } },
                h("div", { class: "left-container" },
                    h("gxg-icon", { slot: "icon", type: "gemini-tools/drag", color: "negative", size: "small" }),
                    h("div", { class: "left-container__title" },
                        h("strong", null,
                            this.toolbarTitle,
                            ":")),
                    h("div", { class: "left-container__subtitle" }, this.subtitle)),
                h("div", { class: "right-container" },
                    h("slot", null)))));
    }
    static get is() { return "gxg-toolbar"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() { return {
        "$": ["toolbar.scss"]
    }; }
    static get styleUrls() { return {
        "$": ["toolbar.css"]
    }; }
    static get properties() { return {
        "position": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The toggle arrow position"
            },
            "attribute": "position",
            "reflect": false,
            "defaultValue": "\"bottom\""
        },
        "disabled": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The state of the toggle, wether is disabled or not"
            },
            "attribute": "disabled",
            "reflect": true,
            "defaultValue": "false"
        },
        "subtitle": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The toolbar title"
            },
            "attribute": "subtitle",
            "reflect": false
        },
        "toolbarTitle": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The toolbar subtitle"
            },
            "attribute": "toolbar-title",
            "reflect": false
        }
    }; }
    static get states() { return {
        "rtl": {}
    }; }
}
