import { Component, h, Host, Element, Event, State, Prop } from "@stencil/core";
export class TreeItem {
    constructor() {
        this.hasChildren = false;
        /**
         * The state of the tree-item, wether it is disabled or not
         */
        this.disabled = false;
        /**
         * The tree item icon
         */
        this.icon = null;
        this.open = false;
    }
    componentDidLoad() {
        const slottedTree = this.el.querySelector("gxg-tree");
        if (slottedTree !== null) {
            if (slottedTree.nodeName === "GXG-TREE") {
                this.hasChildren = true;
                this.numberOfChildItems = slottedTree.childNodes.length - 1;
                this.treeContainerMaxHeight = (28 * this.numberOfChildItems) / 2 + "px";
                this.el.style.setProperty("--treeContainerMaxHeight", this.treeContainerMaxHeight);
                //set animation duration
                const animationDuration = this.numberOfChildItems * 0.03 + "s";
                this.el.style.setProperty("--animation-duration", animationDuration);
            }
        }
        this.el.style.setProperty("--treeContainerMaxHeight", "0");
    }
    getClickHandler(onClick, onDblClick, delay) {
        let timeoutID = null;
        delay = delay || 250;
        return function (event) {
            if (!timeoutID) {
                timeoutID = setTimeout(function () {
                    onClick(event);
                    timeoutID = null;
                }, delay);
            }
            else {
                timeoutID = clearTimeout(timeoutID);
                onDblClick(event);
            }
        };
    }
    render() {
        return (h(Host, { tabindex: "0", class: {
                disabled: this.disabled
            } },
            h("li", { class: {
                    closed: !this.open
                } },
                h("div", { class: "wrapper", onClick: this.getClickHandler(function () {
                        //single clicked
                        this.el.focus();
                        this.itemClicked.emit(this);
                    }.bind(this), function () {
                        this.el.focus();
                        //double clicked
                        this.open = !this.open;
                    }.bind(this), 250) },
                    (this.hasChildren && this.open) || !this.hasChildren ? (h("gxg-icon", { size: "small", type: "gemini-tools/minus", class: {
                            "fold-unfold": true,
                            "no-icon": this.icon === null
                        } })) : (h("gxg-icon", { size: "small", type: "gemini-tools/add", class: {
                            "fold-unfold": true,
                            "no-icon": this.icon === null
                        } })),
                    h("gxg-icon", { size: "small", type: this.icon }),
                    h("slot", null)),
                this.open ? h("slot", { name: "tree" }) : null)));
    }
    static get is() { return "gxg-tree-item"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() { return {
        "$": ["tree-item.scss"]
    }; }
    static get styleUrls() { return {
        "$": ["tree-item.css"]
    }; }
    static get properties() { return {
        "disabled": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The state of the tree-item, wether it is disabled or not"
            },
            "attribute": "disabled",
            "reflect": true,
            "defaultValue": "false"
        },
        "icon": {
            "type": "any",
            "mutable": false,
            "complexType": {
                "original": "any",
                "resolved": "any",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The tree item icon"
            },
            "attribute": "icon",
            "reflect": false,
            "defaultValue": "null"
        }
    }; }
    static get states() { return {
        "hasChildren": {},
        "open": {},
        "numberOfChildItems": {},
        "treeContainerMaxHeight": {}
    }; }
    static get events() { return [{
            "method": "itemClicked",
            "name": "itemClicked",
            "bubbles": true,
            "cancelable": true,
            "composed": true,
            "docs": {
                "tags": [],
                "text": "(This event is for internal use)"
            },
            "complexType": {
                "original": "any",
                "resolved": "any",
                "references": {}
            }
        }]; }
    static get elementRef() { return "el"; }
}
